pub struct Reference {
pub name: String,
pub location: Location,
pub definition: Option<Location>,
}Expand description
A reference to a symbol, with optional resolved definition.
Fields
name: Stringlocation: Locationdefinition: Option<Location>Definition this reference resolves to, if resolvable via scope walk.